==> ZenTaoPMS.17.0.beta1.php7.1.zip: zentaopms/extension/biz/deploy/lang/fr.php <==
<?php
$lang->deploy->common           = 'Plan de dploiement';
$lang->deploy->create           = 'Crer un Plan de dploiement';
$lang->deploy->view             = 'Dtail Dploiement';
$lang->deploy->finish           = 'Termin';
$lang->deploy->finishAction     = 'Terminer le dploiement';
$lang->deploy->edit             = 'Editer';
$lang->deploy->editAction       = 'Editer Dploiement';
$lang->deploy->delete           = 'Supprimer';
$lang->deploy->deleteAction     = 'Supprimer Dploiement';
$lang->deploy->activate         = 'Activer';
$lang->deploy->activateAction   = 'Activer dploiement';
$lang->deploy->browse           = 'Deploiement';
$lang->deploy->scope            = 'Scope Dploiement';
$lang->deploy->manageScope      = 'Grer le Scope';
$lang->deploy->cases            = 'CasTests';
$lang->deploy->notify           = 'Notifier';
$lang->deploy->casesAction      = 'CasTests Dploys';
$lang->deploy->linkCases        = 'Associer CasTest';
$lang->deploy->unlinkCase       = 'Dissocier CasTest';
$lang->deploy->steps            = 'Etape Dploiement';
$lang->deploy->manageStep       = 'Grer Etape';
$lang->deploy->finishStep       = 'Finir Etape';
$lang->deploy->activateStep     = 'Activer Etape';
$lang->deploy->assignTo         = 'Assigner ';
$lang->deploy->assignAction     = 'Assigner Etape';
$lang->deploy->editStep         = 'Editer Etape';
$lang->deploy->deleteStep       = 'Supprimer Etape';
$lang->deploy->viewStep         = 'Dtail Etape';
$lang->deploy->batchUnlinkCases = 'Dissocier par lot';
$lang->deploy->createdDate      = 'Date cration';

$lang->deploy->name       = 'Nom du Plan';
$lang->deploy->desc       = 'Description';
$lang->deploy->members    = 'Membres';
$lang->deploy->hosts      = 'Serveurs';
$lang->deploy->service    = 'Service';
$lang->deploy->product    = 'Product';
$lang->deploy->release    = 'Release';
$lang->deploy->package    = 'Package URL';
$lang->deploy->begin      = 'Dbut';
$lang->deploy->end        = 'Fin';
$lang->deploy->status     = 'Statut';
$lang->deploy->owner      = 'Propritaire';
$lang->deploy->stage      = 'Phase';
$lang->deploy->ditto      = 'Idem';
$lang->deploy->manageAB   = 'Grer';
$lang->deploy->title      = 'Titre';
$lang->deploy->content    = 'Contenu';
$lang->deploy->assignedTo = 'Assign';
$lang->deploy->finishedBy = 'Fini par';
$lang->deploy->createdBy  = 'Cr par';
$lang->deploy->result     = 'Resultat';
$lang->deploy->updateHost = 'Mise jour Serveurs';
$lang->deploy->removeHost = 'Serveurs supprimer';
$lang->deploy->addHost    = 'Nouveau Serveur';
$lang->deploy->hadHost    = 'Hberg';

$lang->deploy->lblBeginEnd = 'Dure';
$lang->deploy->lblBasic    = 'Information de Base';
$lang->deploy->lblProduct  = 'Liens';
$lang->deploy->lblMonth    = 'Courant';
$lang->deploy->toggle      = 'Bascule';

$lang->deploy->monthFormat = 'M Y';

$lang->deploy->statusList['wait'] = 'En attente';
$lang->deploy->statusList['done'] = 'Fait';

$lang->deploy->dateList['today']     = "Aujourd'hui";
$lang->deploy->dateList['tomorrow']  = 'Demain';
$lang->deploy->dateList['thisweek']  = 'Cette semaine';
$lang->deploy->dateList['thismonth'] = 'Ce mois';
$lang->deploy->dateList['done']      = $lang->deploy->statusList['done'];

$lang->deploy->stageList['wait']    = 'Avant dploiement';
$lang->deploy->stageList['doing']   = 'En Dploiement';
$lang->deploy->stageList['testing'] = "Tests d'acceptance";
$lang->deploy->stageList['done']    = 'Aprs Dploiement';

$lang->deploy->resultList['']        = '';
$lang->deploy->resultList['success'] = 'Fait';
$lang->deploy->resultList['fail']    = 'Echec';

$lang->deploy->confirmDelete     = 'Voulez-vous supprimer ce dploiement ?';
$lang->deploy->confirmDeleteStep = 'Voulez-vous supprimer cette tape ?';
$lang->deploy->errorTime         = "L'heure de fin doit tre > l'heure de dbut !";
$lang->deploy->errorStatusWait   = 'If the status is Waiting, the FinishedBy should be empty';
$lang->deploy->errorStatusDone   = "Si l'tat est En attente, FiniPar doit tre vide";
$lang->deploy->errorOffline      = "Les serveurs dans Supprimer et Ajouter pour un service ne peuvent pas l'tre en mme temps.";
$lang->deploy->resultNotEmpty    = 'Le rsultat ne peut pas tre vide';

$lang->deploystep = new stdClass();
$lang->deploystep->status       = $lang->deploy->status;
$lang->deploystep->assignedTo   = $lang->deploy->assignedTo;
$lang->deploystep->finishedBy   = $lang->deploy->finishedBy;
$lang->deploystep->finishedDate = 'Finished Date';
$lang->deploystep->begin        = $lang->deploy->begin;
$lang->deploystep->end          = $lang->deploy->end;

==> ZenTaoPMS.18.0.beta1.php8.0.zip: zentaopms/extension/biz/deploy/lang/fr.php <==
<?php
$lang->deploy->common           = 'Plan de dploiement';
$lang->deploy->create           = 'Crer un plan de dploiement';
$lang->deploy->view             = 'Dtails du dploiement';
$lang->deploy->finish           = 'Termin';
$lang->deploy->finishAction     = 'Dploiement termin';
$lang->deploy->edit             = 'Editer';
$lang->deploy->editAction       = 'Editer dploiement';
$lang->deploy->delete           = 'Supprimer';
$lang->deploy->deleteAction     = 'Supprimer dploiement';
$lang->deploy->deleted          = 'Deleted';
$lang->deploy->activate         = 'Activer';
$lang->deploy->activateAction   = 'Activer dploiement';
$lang->deploy->browse           = 'Deploiement';
$lang->deploy->scope            = 'Scope dploiement';
$lang->deploy->manageScope      = "Champ d'application de la gestion";
$lang->deploy->cases            = 'CasTests';
$lang->deploy->notify           = 'Notifier';
$lang->deploy->casesAction      = 'Cas de dploiement';
$lang->deploy->linkCases        = 'Associer CasTest';
$lang->deploy->unlinkCase       = 'Dissocier CasTest';
$lang->deploy->steps            = 'Etape dploiement';
$lang->deploy->manageStep       = '07tapes administratives';
$lang->deploy->finishStep       = 'Finir Etape';
$lang->deploy->activateStep     = 'Activer Etape';
$lang->deploy->assignTo         = 'Assigner ';
$lang->deploy->assignAction     = 'Assigner Etape';
$lang->deploy->editStep         = 'Editer Etape';
$lang->deploy->deleteStep       = 'Supprimer Etape';
$lang->deploy->viewStep         = 'Dtails Etape';
$lang->deploy->batchUnlinkCases = 'Dissocier par lot';
$lang->deploy->createdDate      = 'Date de cration';

$lang->deploy->name       = 'Nom du Plan';
$lang->deploy->desc       = 'Description';
$lang->deploy->members    = 'Membres';
$lang->deploy->hosts      = 'Serveurs';
$lang->deploy->service    = 'Service';
$lang->deploy->product    = 'Product';
$lang->deploy->release    = 'Release';
$lang->deploy->package    = 'Package URL';
$lang->deploy->begin      = "C'est parti";
$lang->deploy->end        = 'Fin';
$lang->deploy->status     = 'Statut';
$lang->deploy->owner      = 'Propritaire';
$lang->deploy->stage      = 'Phase';
$lang->deploy->ditto      = 'Idem';
$lang->deploy->manageAB   = 'Gestion';
$lang->deploy->title      = 'Titre';
$lang->deploy->content    = 'Contenu';
$lang->deploy->assignedTo = 'Assign';
$lang->deploy->finishedBy = 'Fini par';
$lang->deploy->createdBy  = 'Crateur';
$lang->deploy->result     = 'Resultat';
$lang->deploy->updateHost = 'Mise jour Serveurs';
$lang->deploy->removeHost = 'Serveurs supprimer';
$lang->deploy->addHost    = 'Nouveau Serveur';
$lang->deploy->hadHost    = 'Hbergement';

$lang->deploy->lblBeginEnd = 'Priode';
$lang->deploy->lblBasic    = 'Information de Base';
$lang->deploy->lblProduct  = 'Liens';
$lang->deploy->lblMonth    = 'Courant';
$lang->deploy->toggle      = 'Bascule';

$lang->deploy->monthFormat = 'M Y';

$lang->deploy->statusList['wait'] = 'En attente';
$lang->deploy->statusList['done'] = 'Fait';

$lang->deploy->dateList['today']     = "Aujourd'hui";
$lang->deploy->dateList['tomorrow']  = 'Demain';
$lang->deploy->dateList['thisweek']  = 'Cette semaine';
$lang->deploy->dateList['thismonth'] = 'Ce mois';
$lang->deploy->dateList['done']      = $lang->deploy->statusList['done'];

$lang->deploy->stageList['wait']    = 'Avant dploiement';
$lang->deploy->stageList['doing']   = 'En dploiement';
$lang->deploy->stageList['testing'] = "Tests d'acceptance";
$lang->deploy->stageList['done']    = 'Aprs dploiement';

$lang->deploy->resultList['']        = '';
$lang->deploy->resultList['success'] = 'Fait';
$lang->deploy->resultList['fail']    = 'Echec';

$lang->deploy->confirmDelete     = 'Voulez - vous supprimer ce dploiement?';
$lang->deploy->confirmDeleteStep = 'Voulez - vous supprimer cette tape?';
$lang->deploy->errorTime         = "L'heure de fin doit tre suprieure  l'heure de dbut!";
$lang->deploy->errorStatusWait   = 'If the status is Waiting, the FinishedBy should be empty';
$lang->deploy->errorStatusDone   = "Finishby ne doit pas tre vide si l'tat est termin";
$lang->deploy->errorOffline      = "L'h00te dans la suppression et l'ajout du service ne peut pas exister en mme temps.";
$lang->deploy->resultNotEmpty    = 'Le rsultat ne peut pas tre vide';

$lang->deploystep = new stdClass();
$lang->deploystep->status       = $lang->deploy->status;
$lang->deploystep->assignedTo   = $lang->deploy->assignedTo;
$lang->deploystep->finishedBy   = $lang->deploy->finishedBy;
$lang->deploystep->finishedDate = 'Finished Date';
$lang->deploystep->begin        = $lang->deploy->begin;
$lang->deploystep->end          = $lang->deploy->end;
